@@ -2,6 +2,7 @@ import codecs
 import datetime
 import socket
 import logging
+import construct
 from typing import Any, List, Optional  # noqa: F401
 
 from .protocol import Message
@@ -14,6 +15,11 @@ class DeviceException(Exception):
     pass
 
 
+class DeviceError(DeviceException):
+    """Exception communicating an error delivered by the target device."""
+    pass
+
+
 class DeviceInfo:
     """Container of miIO device information.
     Hardware properties such as device model, MAC address, memory information,
@@ -112,8 +118,7 @@ class Device:
         self._timeout = 5
         self._device_ts = None  # type: datetime.datetime
         self.__id = start_id
-        self._devtype = None
-        self._serial = None
+        self._device_id = None
 
     def do_discover(self) -> Message:
         """Send a handshake to the device,
@@ -126,14 +131,12 @@ class Device:
         :raises DeviceException: if the device could not be discovered."""
         m = Device.discover(self.ip)
         if m is not None:
-            self._devtype = m.header.value.devtype
-            self._serial = m.header.value.serial
+            self._device_id = m.header.value.device_id
             self._device_ts = m.header.value.ts
             if self.debug > 1:
                 _LOGGER.debug(m)
-            _LOGGER.debug("Discovered %s %s with ts: %s, token: %s",
-                          self._devtype,
-                          self._serial,
+            _LOGGER.debug("Discovered %s with ts: %s, token: %s",
+                          self._device_id,
                           self._device_ts,
                           codecs.encode(m.checksum, 'hex'))
         else:
@@ -176,9 +179,9 @@ class Device:
                     return m
 
                 if addr[0] not in seen_addrs:
-                    _LOGGER.info("  IP %s: %s - token: %s",
+                    _LOGGER.info("  IP %s (ID: %s) - token: %s",
                                  addr[0],
-                                 m.header.value.devtype,
+                                 m.header.value.device_id.decode(),
                                  codecs.encode(m.checksum, 'hex'))
                     seen_addrs.append(addr[0])
             except socket.timeout:
@@ -210,18 +213,16 @@ class Device:
 
         send_ts = self._device_ts + datetime.timedelta(seconds=1)
         header = {'length': 0, 'unknown': 0x00000000,
-                  'devtype': self._devtype, 'serial': self._serial,
-                  'ts': send_ts}
+                  'device_id': self._device_id, 'ts': send_ts}
 
         msg = {'data': {'value': cmd},
                'header': {'value': header},
                'checksum': 0}
-        ctx = {'token': self.token}
-        m = Message.build(msg, ctx)
+        m = Message.build(msg, token=self.token)
         _LOGGER.debug("%s:%s >>: %s", self.ip, self.port, cmd)
         if self.debug > 1:
             _LOGGER.debug("send (timeout %s): %s",
-                          self._timeout, Message.parse(m, ctx))
+                          self._timeout, Message.parse(m, token=self.token))
 
         s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
         s.settimeout(self._timeout)
@@ -234,8 +235,9 @@ class Device:
 
         try:
             data, addr = s.recvfrom(1024)
-            m = Message.parse(data, ctx)
+            m = Message.parse(data, token=self.token)
             self._device_ts = m.header.value.ts
+            self._device_id = m.header.value.device_id
             if self.debug > 1:
                 _LOGGER.debug("recv from %s: %s", addr[0], m)
 
@@ -245,10 +247,17 @@ class Device:
                           m.header.value.ts,
                           m.data.value["id"],
                           m.data.value)
+            if "error" in m.data.value:
+                raise DeviceError(m.data.value["error"])
+
             try:
                 return m.data.value["result"]
             except KeyError:
                 return m.data.value
+        except construct.core.ChecksumError as ex:
+            raise DeviceException("Got checksum error which indicates use "
+                                  "of an invalid token. "
+                                  "Please check your token!") from ex
         except OSError as ex:
             _LOGGER.error("Got error when receiving: %s", ex)
             if retry_count > 0:
@@ -256,7 +265,7 @@ class Device:
                                 "retries left: %s", retry_count)
                 self.__id += 100
                 return self.send(command, parameters, retry_count - 1)
-            raise DeviceException from ex
+            raise DeviceException("No response from the device") from ex
 
     def raw_command(self, cmd, params):
         """Send a raw command to the device.
